@@ -1,5 +1,6 @@
 import os
 import pathlib
+import sys
 from typing import Any
 
 import pkg_resources
@@ -37,6 +38,13 @@ HUGGINGFACE_TRANSFORMER_MODULE_NAME = {
     'transformers'
 }
 
+# lists of versions supported by the scaffold+base_images
+PYTHON_VERSIONS = {
+    'py37',
+    'py38',
+    'py39',
+}
+
 
 def pip_freeze():
     """
@@ -113,10 +121,19 @@ def _model_class(model: Any):
     return model.__class__
 
 
+def infer_python_version() -> str:
+    python_major_minor = f'py{sys.version_info.major}{sys.version_info.minor}'
+    # might want to fix up this logic
+    if python_major_minor not in PYTHON_VERSIONS:
+        python_major_minor = None
+    return python_major_minor
+
+
 def infer_model_information(model: Any) -> ModelBuildStageOne:
     model_class = _model_class(model)
     model_framework = infer_model_framework(model_class)
     model_type = model_class.__name__
+
     return ModelBuildStageOne(
         model_type,
         model_framework,
