@@ -18,18 +18,33 @@ from common.serialization import (
 from pythonjsonlogger import jsonlogger
 
 
-class B10HTTPHandler(HTTPHandler):
+def _assign_request_to_inputs_instances_after_validation(request):
+    # we will treat "instances" and "inputs" the same
+    if "instances" in request and "inputs" not in request:
+        request["inputs"] = request["instances"]
+    elif "inputs" in request and "instances" not in request:
+        request["instances"] = request["inputs"]
+    return request
+
+
+class B10HTTPBinaryHandler(HTTPHandler):
     def validate(self, request):
         if ("instances" in request and not isinstance(request["instances"], (list, np.ndarray))) or \
            ("inputs" in request and not isinstance(request["inputs"], (list, np.ndarray))):
             raise tornado.web.HTTPError(
                 status_code=HTTPStatus.BAD_REQUEST,
-                reason="Expected \"instances\" or \"inputs\" to be a list"
+                reason="Expected \"instances\" or \"inputs\" to be a list or NumPy ndarray"
             )
-        return request
+        return _assign_request_to_inputs_instances_after_validation(request)
 
 
-class B10PredictHandler(B10HTTPHandler):
+class B10HTTPHandler(HTTPHandler):
+    def validate(self, request):
+        request = super().validate(request)
+        return _assign_request_to_inputs_instances_after_validation(request)
+
+
+class B10PredictHandler(B10HTTPBinaryHandler):
     def post(self, name: str):
         model = self.get_model(name)
         try:
@@ -43,10 +58,17 @@ class B10PredictHandler(B10HTTPHandler):
         request = self.validate(request)
         response = model.predict(request)
         response = model.postprocess(response)
-        self.write(b10_msgpack_serialize(response))
+        try:
+            final_response = b10_msgpack_serialize(response)
+        except Exception as e:
+            raise tornado.web.HTTPError(
+                status_code=HTTPStatus.INTERNAL_SERVER_ERROR,
+                reason="Unable to serialize model prediction to response: %s" % e
+            )
+        self.write(final_response)
 
 
-class B10ExplainHandler(B10HTTPHandler):
+class B10ExplainHandler(B10HTTPBinaryHandler):
     def post(self, name: str):
         model = self.get_model(name)
         try:
@@ -60,10 +82,17 @@ class B10ExplainHandler(B10HTTPHandler):
         request = self.validate(request)
         response = model.explain(request)
         response = model.postprocess(response)
-        self.write(response)
+        try:
+            final_response = b10_msgpack_serialize(response)
+        except Exception as e:
+            raise tornado.web.HTTPError(
+                status_code=HTTPStatus.INTERNAL_SERVER_ERROR,
+                reason="Unable to serialize model prediction to response: %s" % e
+            )
+        self.write(final_response)
 
 
-class PredictHandler(HTTPHandler):
+class PredictHandler(B10HTTPHandler):
     def post(self, name: str):
         model = self.get_model(name)
         try:
@@ -77,10 +106,17 @@ class PredictHandler(HTTPHandler):
         request = self.validate(request)
         response = model.predict(request)
         response = model.postprocess(response)
-        self.write(json.dumps(response, cls=DeepNumpyEncoder))
+        try:
+            final_response = json.dumps(response, cls=DeepNumpyEncoder)
+        except Exception as e:
+            raise tornado.web.HTTPError(
+                status_code=HTTPStatus.INTERNAL_SERVER_ERROR,
+                reason="Unable to serialize model prediction to response: %s" % e
+            )
+        self.write(final_response)
 
 
-class ExplainHandler(HTTPHandler):
+class ExplainHandler(B10HTTPHandler):
     def post(self, name: str):
         model = self.get_model(name)
         try:
@@ -94,7 +130,14 @@ class ExplainHandler(HTTPHandler):
         request = self.validate(request)
         response = model.explain(request)
         response = model.postprocess(response)
-        self.write(json.dumps(response, cls=DeepNumpyEncoder))
+        try:
+            final_response = json.dumps(response, cls=DeepNumpyEncoder)
+        except Exception as e:
+            raise tornado.web.HTTPError(
+                status_code=HTTPStatus.INTERNAL_SERVER_ERROR,
+                reason="Unable to serialize model prediction to response: %s" % e
+            )
+        self.write(final_response)
 
 
 class B10Server(KFServer):
