@@ -54,8 +54,8 @@ ms.predict([[0,0,0,0]])
 
 EMBEDDING_REQUIREMENTS = """
 tensorflow-hub==0.10.0
-tensorflow==2.4.0
-scikit-learn==0.23.2
+tensorflow==2.5.0
+scikit-learn==1.0.2
 """
 
 EMBEDDING_UTIL_CODE = """
@@ -107,32 +107,33 @@ class MyEmbeddingModel:
         }
 
 """
-
+from pathlib import Path
+from baseten_scaffolding.scaffold.build import scaffold_custom
+path = Path('test_folder')
+path.mkdir(parents=True, exist_ok=True)
 # Create the model file
-with open('embedding_model.py', 'w') as f:
+with open('test_folder/embedding_model.py', 'w') as f:
     f.write(EMBEDDING_MODEL_CODE)
 
 # Create some utils file
-with open('embedding_util.py', 'w') as f:
+with open('test_folder/embedding_util.py', 'w') as f:
     f.write(EMBEDDING_UTIL_CODE)
 
 # Create the requirements file
-with open('embedding_reqs.txt', 'w') as f:
+with open('test_folder/embedding_reqs.txt', 'w') as f:
     f.write(EMBEDDING_REQUIREMENTS)
 
 # Create a fake dataset to include with the deployment
-from embedding_util import create_reference_embeddings
+from test_folder.embedding_util import create_reference_embeddings
 create_reference_embeddings()
 
-from baseten_scaffolding.definitions.custom import CustomScaffoldDefinition
-scaffold = CustomScaffoldDefinition(
-    None,
-    model_files=['embedding_model.py', 'embedding_util.py', 'embeddings.npy'],
-    path_to_scaffold='test_custom',
-    requirements_file='embedding_reqs.txt',
+scaffold = scaffold_custom(
+    model_files=['test_folder/embedding_model.py', 'test_folder/embedding_util.py', 'embeddings.npy'],
+    target_directory='test_custom',
+    requirements_file='test_folder/embedding_reqs.txt',
     model_class='MyEmbeddingModel'
 )
-
+scaffold.docker_build_string
 scaffold.predict(['hello world', 'bar baz'])
 
 ##############################################################################
